# datasette-render-binary

[![PyPI](https://img.shields.io/pypi/v/datasette-render-binary.svg)](https://pypi.org/project/datasette-render-binary/)
[![Changelog](https://img.shields.io/github/v/release/simonw/datasette-render-binary?include_prereleases&label=changelog)](https://github.com/simonw/datasette-render-binary/releases)
[![Tests](https://github.com/simonw/datasette-render-binary/workflows/Test/badge.svg)](https://github.com/simonw/datasette-render-binary/actions?query=workflow%3ATest)
[![License](https://img.shields.io/badge/license-Apache%202.0-blue.svg)](https://github.com/simonw/datasette-render-binary/blob/main/LICENSE)

Datasette plugin for rendering binary data.

Install this plugin in the same environment as Datasette to enable this new functionality:

    pip install datasette-render-binary

Binary data in cells will now be rendered as a mixture of characters and octets.

![Screenshot](https://raw.githubusercontent.com/simonw/datasette-render-binary/master/example.png)
